@@ -1,4 +1,6 @@
 import json
+import numbers
+
 from pyqldb.driver.qldb_driver import QldbDriver
 from amazon.ion.json_encoder import IonToJSONEncoder
 
@@ -24,16 +26,48 @@ class QLDBDriver:
 
     def create_table(self, table_name, primary_key = None):
         statement = f"CREATE TABLE {table_name}"
-        cursor = self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
+        self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
 
         if primary_key is not None:
             statement = f"CREATE INDEX ON {table_name}({primary_key})"
-            cursor = self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
+            self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
 
 
     def drop_table(self, table_name):
         statement = f"DROP TABLE {table_name}"
-        cursor = self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
+        self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
+
+
+    def add_attribute(self, table_name, identifier, attribute_name, value = None):
+        if isinstance(value, str):
+            default_value = f"'{value}'"
+        elif isinstance(value, numbers.Number):
+            default_value = f"{value}"
+        elif value is None:
+            default_value = "null"
+
+        statement = f"SELECT {identifier} FROM {table_name}"
+        
+        ids = self.query(statement)
+
+        for id in ids:
+            if isinstance(id[identifier], str):
+                statement = f"FROM {table_name} WHERE {identifier} = '{id[identifier]}' SET {attribute_name} = {default_value}"
+            elif isinstance(id[identifier], numbers.Number):
+                statement = f"FROM {table_name} WHERE {identifier} = {id[identifier]} SET {attribute_name} = {default_value}"
+
+            self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
+
+
+    def remove_attribute(self, table_name, identifier, attribute_name):
+        statement = f"SELECT {identifier} FROM {table_name}"
+        
+        ids = self.query(statement)
+
+        for id in ids:
+            statement = f"FROM {table_name} WHERE {identifier} = {id[identifier]} REMOVE {attribute_name}"
+
+            self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
 
 
     def list_tables(self):
@@ -47,7 +81,7 @@ class QLDBDriver:
 
     def insert_data(self, table_name, data):
         statement = f"INSERT INTO {table_name} `{json.dumps(data)}`"
-        cursor = self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
+        self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
 
 
     def update_data(self, table_name, primary_key_field, primary_key_value,data):
@@ -56,7 +90,7 @@ class QLDBDriver:
                 SET x = {str(data)} 
             WHERE x.{primary_key_field} = {primary_key_value}"""
         
-        cursor = self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
+        self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
 
 
     def query(self, statement):
@@ -73,3 +107,7 @@ class QLDBDriver:
             raise Exception('more than 1 result recived')
 
         return collection[0]
+
+
+    def execute_statement(self, statement):
+        self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
